source("radio_fragment_functions.R")
library(ggplot2)
library(plyr)

topic <- "clim" #clim for climate, gun for gun policy, immi for immigration



# Get data ----------------------------------------------------------------

#get coding results
result <- read.csv(paste0("data/coding_result_", topic, ".csv"))
result$show_week <- factor(paste(result$show_name, result$week, sep="_"))

#get show classification results
show_class <- read.csv("data/ideology_predictions.csv", stringsAsFactors=F)

#find which shows are NPR shows (show_matches.csv is for unifying show names)
NPRshows <- read.csv("data/NPR_shows.csv")
show_match <- read.csv("data/show_matches.csv", stringsAsFactors=F)
NPRshows <- merge(NPRshows, show_match, by.x="show_name", by.y="origin", all.x=T)

#get event weeks during which we had an airing of the show,
#as no mentions could also mean the show was not on
airings <- read.csv("data/airing_confidence.csv")
df_prepost <- read.csv("data/event_prepost.csv")
week <- as.factor(airings$date)
levels(week) <- sapply(levels(week), event_week, df_prepost, topic)
rec_weeks <- tapply(week, as.character(airings$show), unique)
show_weeks <- sapply(1:length(rec_weeks), function(i){
    event_weeks <- setdiff(as.character(rec_weeks[[i]]), "none")
    if(length(event_weeks) == 0){
      return(NULL)
    } else {
      return(paste(names(rec_weeks)[i], event_weeks, sep="_"))
    }
  })
obs_show_weeks <- data.frame(show_week=unlist(show_weeks))



# Summarize by show-week --------------------------------------------------

#mentions per show-week (total, and by frame)
d <- as.data.frame(table(result$show_week))
colnames(d) <- c("show_week","Total")
d2 <- as.data.frame.matrix(table(result$show_week, result$code))
d2$show_week <- rownames(d2)
d <- merge(d, d2, all=T)

#add show-weeks with no mentions
d <- merge(obs_show_weeks, d, all.x=T)
d[is.na(d)] <- 0

#split show-week
shwk <- strsplit(as.character(d$show_week), "_")
d$show <- factor(sapply(shwk, "[[", 1))
d$event <- factor(sapply(shwk, "[[", 2))
d$prepost <- factor(sapply(shwk, "[[", 3), levels=c("pre","post"))

#add show political/ideology class
d <- merge(d, show_class, by.x = "show", by.y="Show", all.x=T)
d$NPR <- d$show %in% NPRshows$destination



# Get dependent variables -------------------------------------------------

if(topic=="clim"){
  conc_col <- "Convinced"
  unconc_col <- "Skeptical"
} else if(topic=="gun"){
  conc_col <- "Antigun"
  unconc_col <- "Progun"
} else if(topic=="immi"){
  conc_col <- "Tough on immigration"
  unconc_col <- "Supporting immigration"
}

#proportion "concerned" about issue
d$prop_conc <- d[,conc_col] / (d[,conc_col] + d[,unconc_col])



# Descriptives ------------------------------------------------------------

#total mentions (rounded)
mround <- function(x, base){
  base*round(x/base)
}
mround(sum(d$Total), 50)
mround(sum(d$Total - d$`Not coded`), 50)

#total political show-weeks
sum(d$Prob.political > .5, na.rm=T)

#avg. number of mentions in pre-weeks
#on political shows (across ideologies)
mean(d$Total[d$Prob.political > .5 & d$prepost == "pre"], na.rm=T)

#mentions uncoded due to outdated schedules
sum(d$`Not coded`[d$Total < 25])

#shows from NPR classified as liberal
show_class$pol_NPR <- show_class$Prob.political > .5 & (show_class$Show %in% NPRshows$destination)
sum(show_class$pol_NPR)
summary(show_class[show_class$pol_NPR,"Prob.liberal"])



# Add hours recorded ------------------------------------------------------

#get minutes per week, per show, by callsign
show_times <- read.csv("data/station_show_times_corrected.csv")
show_times$show_wkday <- paste(show_times$show, show_times$start_day_tz)
mins_per_week <- ddply(show_times, .(show, callsign), summarize,
                       tot_mins=sum(mins))

#take median number of minutes over all callsigns
median_mins <- tapply(mins_per_week$tot_mins, mins_per_week$show, median)
d$mins <- median_mins[as.character(d$show)]



# Write to file -----------------------------------------------------------

write.csv(d, paste0("data/mentions_showweek_", topic, ".csv"), row.names=F)
