library(ggplot2)

topic <- "clim" #clim for climate, gun for gun policy, immi for immigration

#get data
counts <- read.csv(paste0("predictions_CIs/pred_count_", topic, ".csv"))
positions <- read.csv(paste0("predictions_CIs/pred_position_", topic, ".csv"))
library(dplyr)
counts$prepost <- recode(counts$prepost, pre = "before", post = "after")
counts$prepost <- factor(counts$prepost, levels=c("before","after"))
positions$prepost <- recode(positions$prepost, pre = "before", post = "after")
positions$prepost <- factor(positions$prepost, levels=c("before","after"))

#full topic name (and code order)
if(topic=="clim"){
  fulltop <- "climate"
  top_position <- "convinced on climate"
} else if(topic=="gun"){
  fulltop <- "gun policy"
  top_position <- "anti-gun"
} else if(topic=="immi"){
  fulltop <- "immigration"
  top_position <- "tough on immigration"
}

#count barplot
pdf(paste0("figures/count_barplot_", topic, ".pdf"), 6, 4)
ggplot(counts, aes(x=ideology, y=count, fill=prepost)) + 
  geom_bar(position=position_dodge(), stat="identity") +
  geom_errorbar(aes(ymin=CI_lo, ymax=CI_hi), width=.1, position=position_dodge(.9) ) +
  theme_light() +
  theme(axis.title.x=element_blank(),
        panel.grid.minor = element_blank(),
        legend.title=element_blank(),
        axis.title.y = element_text(size=14),
        text = element_text(size=16)) +
  ylab(paste0("Number of mentions of ", fulltop)) +
  scale_fill_manual(values = c("deepskyblue4","darkorange"))
dev.off()

#position barplot
pdf(paste0("figures/position_barplot_", topic, ".pdf"), 6, 4)
ggplot(positions, aes(x=ideology, y=position*100, fill=prepost)) + 
  geom_bar(position=position_dodge(), stat="identity") +
  geom_errorbar(aes(ymin=CI_lo*100, ymax=CI_hi*100), width=.1, position=position_dodge(.9) ) +
  theme_light() +
  theme(axis.title.x=element_blank(),
        panel.grid.minor = element_blank(),
        legend.title=element_blank(),
        axis.title.y = element_text(size=13),
        text = element_text(size=15)) +
  ylab(paste0("% of mentions that are ", top_position)) +
  scale_fill_manual(values = c("deepskyblue4","darkorange")) +
  ylim(0, 100)
dev.off()