setwd("~/Dropbox (MIT)/dissertation/cortico/models")
library(plyr)
topic <- "immi"


##Data prep

#get data
d_all <- read.csv(paste0("mentions_showweek_", topic, ".csv"))

#keep only political shows
d_all$political <- d_all$Prob.political >= .5
d <- d_all[d_all$political & !is.na(d_all$political),]

#find shows with 'News' in the name
d$news <- grepl("news", tolower(d$show))

#find shows on 'All News' format stations
show_times <- read.csv("../schedules/station_show_times_corrected.csv", na.string="", stringsAsFactors=F)
stations <- read.csv("../stations/stations.csv")
show_times <- merge(show_times, stations, by.x="callsign", by.y = "Callsign")
newsstat_names <- unique(show_times[show_times$Format == "News","show"])
d$newsstat <- d$show %in% newsstat_names

#find NPR shows
NPRshows <- read.csv("../schedules/NPR/NPR_shows.csv")
show_match <- read.csv("../schedules/show_matches.csv", stringsAsFactors=F)
NPRshows <- merge(NPRshows, show_match, by.x="show_name", by.y="origin", all.x=T)
NPR_names <- c(NPRshows$destination, "BBC World Service")
d$NPR <- d$show %in% NPR_names

#find shows on 'Public' format stations
pubstat_names <- unique(show_times[show_times$Format == "Public Radio","show"])
d$pubstat <- d$show %in% pubstat_names


##Inspect NPR and news shows

#count coded mentions
if(topic=="clim"){
  d$Coded <- d$Total
} else{
  d$Coded <- d$Total - d$Not.coded - d$Could.not.hear.audio
}

#count proportions of "Neither" mentions
d$prop_nth <- d$Neither/d$Coded

#summarize by show
d_show <- ddply(d, .(show), summarize,
                prop_nth=weighted.mean(prop_nth, Total, na.rm = T),
                prop_conc=weighted.mean(prop_conc, Total, na.rm = T),
                Coded=sum(Coded), Total=sum(Total))
d_show$news <- grepl("news", tolower(d_show$show))
d_show$newsstat <- d_show$show %in% newsstat_names
d_show$NPR <- d_show$show %in% NPR_names
d_show$pubstat <- d_show$show %in% pubstat_names
d_show$prop_favored <- sapply(d_show$prop_conc, function(x) max(x, 1-x))


for(crit in c("news", "NPR", "newsstat", "pubstat")){
  
  message("for shows of type: ", crit)
  
  #subset on this category
  d_sub <- d_show[d_show[,crit],]
  
  #number of political shows
  message("number of such shows (political only): ", nrow(d_sub))
  
  #prop. shows w/ no mention of topic
  #message("% w/ no mentions: ",
  #        round(mean(d_sub$Total == 0), digits = 2))
  
  #proportions "Neither"
  print("% Neither mentions:")
  print(summary(d_sub$prop_nth))
  #tapply(d_sub$prop_nth, list(d_sub$political, d_sub$ideology), mean, na.rm=T)
  
  #imbalance among non-Neither mentions
  print("% of framed mentions going to favored side:")
  print(summary(d_sub$prop_favored))
  
  #overall mention balance
  print("% concerned mentions overall:")
  print(weighted.mean(d_sub$prop_conc, d_sub$Total, na.rm=T))
  
}

#Neither mentions and mention imbalance among non-news, non-NPR shows
d_non <- d_show[!d_show$news & !d_show$NPR,]
#Neither mentions
summary(d_non$prop_nth)
#% of framed mentions going to favored side:
summary(d_non$prop_favored)
