library("xtable")
library(gtools)

for(topic in c("clim","gun","immi")){
  
  ##Read and Prep data
  pred_noNPR <- read.csv(paste0("ideo_npr_app/pred_", topic, "_0.5_0.5.csv"))
  pred_NPR <- read.csv(paste0("ideo_npr_app/pred_withNPR_", topic, ".csv"))
  pred_noNPR$pub <- "nopub"
  pred_NPR$pub <- "pub"
  pred <- smartbind(pred_noNPR, pred_NPR)
  
  #order of table columns
  t <- expand.grid(c("pre","post"), c("count","position"), c("nopub", "pub"))
  col_ord <- paste(t$Var2, t$Var1, t$Var3, sep=".")
  
  #table
  pred$position <- pred$position * 100
  pred$pub_pp <- paste(pred$prepost, pred$pub, sep=".")
  pred <- pred[,c("ideology","count","position","pub_pp")]
  pred_wd <- reshape(pred,
                           idvar = "ideology",
                           timevar = "pub_pp",
                           direction="wide")
  
  #add topic column
  if(topic=="clim"){
    pred_wd$topic <- "climate"
  } else if(topic=="gun"){
    pred_wd$topic <- "gun policy"
  } else if(topic=="immi"){
    pred_wd$topic <- "immigration"
  }
  
  ##Write to LaTeX table
  
  pred_tab <- xtable(pred_wd[,c("topic","ideology",col_ord)],
                     digits=c(1, 1, 1, rep(c(1,1,0,0), 2)))
  print(pred_tab, file=paste0("ideo_npr_app/noNPR_results_", topic, "xxxx.tex"),
        scalebox=1, include.rownames=F, include.colnames=F, only.contents = T)
  
}
