library("xtable")


##Read data

pred_pol <- NULL
pred_ideo <- NULL
for(topic in c("clim","gun","immi")){
  
  message("topic:", topic)
  
  #get results with varying politicalness thresholds
  for(pol_thres in c(.4, .5, .6)){
    
    #message("pol_thres:", pol_thres)
    lib_thres <- .5
    pred <- read.csv(paste0("ideo_npr_app/pred_", topic, "_", pol_thres,
                    "_", lib_thres, ".csv"))
    pred$topic <- topic
    pred_pol <- rbind(pred_pol, pred)
    
  }
  
  #get results with varying ideology windows
  for(lib_thres in c(.5, .6, .7)){
    
    #message("lib_thres:", lib_thres)
    pol_thres <- .5
    pred <- read.csv(paste0("ideo_npr_app/pred_", topic, "_", pol_thres,
                            "_", lib_thres, ".csv"))
    pred$topic <- topic
    pred_ideo <- rbind(pred_ideo, pred)
    
  }
  
}


##Prep data

#order of table columns
t <- expand.grid(c("pre","post"), c("count","position"), c("clim","gun","immi"))
col_ord <- paste(t$Var2, t$Var1, t$Var3, sep=".")

#politicalness threshold table
pred_pol$position <- pred_pol$position * 100
pred_pol$topic_pp <- paste(pred_pol$prepost, pred_pol$topic, sep=".")
pred_pol <- pred_pol[,c("topic_pp", "ideology","count","position",
                        "pol_thres")]
pred_pol_wd <- reshape(pred_pol,
                       idvar = c("ideology","pol_thres"),
                       timevar = "topic_pp",
                       direction="wide")

#ideology threshold table
pred_ideo$position <- pred_ideo$position * 100
pred_ideo$topic_pp <- paste(pred_ideo$prepost, pred_ideo$topic, sep=".")
pred_ideo <- pred_ideo[,c("topic_pp", "ideology","count","position",
                        "lib_thres")]
pred_ideo_wd <- reshape(pred_ideo,
                       idvar = c("ideology","lib_thres"),
                       timevar = "topic_pp",
                       direction="wide")


##Write to LaTeX table

pred_pol_tab <- xtable(pred_pol_wd[,c("pol_thres","ideology",col_ord)],
                       digits=c(1, 1, 1, rep(c(1,1,0,0), 3)))
pred_ideo_tab <- xtable(pred_ideo_wd[,c("lib_thres","ideology",col_ord)],
                        digits=c(1, 1, 1, rep(c(1,1,0,0), 3)))
print(pred_pol_tab, file="ideo_npr_app/pol_thres_results.tex", scalebox=1,
      include.rownames=F, include.colnames=F, only.contents = T, 
      hline.after = c(2,4,6))
print(pred_ideo_tab, file="ideo_npr_app/ideo_thres_results.tex", scalebox=1,
      include.rownames=F, include.colnames=F, only.contents = T, 
      hline.after = c(2,4,6))