library(plyr)
library(ggplot2)

topic <- "immi" #clim for climate, gun for gun policy, immi for immigration

#function to get beginning of the week a date is in
get_weekof <- function(date){
  wkday <- as.POSIXlt(date)$wday
  as.Date(date) - wkday
}

#show airing data
airings <- read.csv("../data/airing_confidence.csv")
airings$weekof <- get_weekof(airings$date)
#TO DO: update to reflect political shows only

#full topic name and loess span
if(topic=="clim"){
  fulltop <- "climate change"
  span <- .15
} else if(topic=="gun"){
  fulltop <- "gun policy"
  span <- .25
} else if(topic=="immi"){
  fulltop <- "immigration"
  span <- .15
}


##Google trends

#get data
prepost <- read.csv("../data/event_prepost.csv")
prepost <- prepost[prepost$topic==topic,]
prepost <- prepost[order(prepost$post_start),]
prepost$pre_start <- as.Date(prepost$pre_start)
prepost$post_end <- as.Date(prepost$post_end)


##Radio mentions

#get mention counts
mentions_tot <- read.csv(paste0("../data/mention_count_", topic, ".csv"))
mentions_tot$date <- as.Date(mentions_tot$date)

#loess smoothing (split into chunks between events)
mentions_tot$Datenum <- as.numeric(mentions_tot$date)
mentions_loess <- do.call(rbind,
  mapply(
  #function fitting loess curve to mentions counts
  #for dates between start and end
  function(start, end, event){
    d <- mentions_tot[mentions_tot$date >= start & 
                        mentions_tot$date < end,]
    loessfit <- loess(count ~ Datenum, d, span=span)
    data.frame(date=d$date,
               count_ls=predict(loessfit),
               post_event=event)
  },
  #periods start and end with beginning of next post-week
  c(min(mentions_tot$date), as.Date(prepost$post_start)),
  c(as.Date(prepost$post_start), max(mentions_tot$date)),
  c("none", prepost$event_abbr),
  SIMPLIFY=FALSE)
)
mentions_tot <- merge(mentions_tot, mentions_loess)

#dates for significant events
if(topic == "clim"){
  event <- data.frame(name=c("Florence landfall","Michael\n landfall"),
                      date=as.Date(c("2018-09-14","2018-10-10")))
  event_xmod <- c(0,8)
  event_ymod <- c(20,20)
} else if(topic == "gun") {
  event <- data.frame(name=c("Santa Fe High School",
                             "Jacksonville Landing",
                             "Pittsburgh Synagogue",
                             "Thousand Oaks"),
                      date=as.Date(c("2018-05-18",
                                     "2018-08-26",
                                     "2018-10-27",
                                     "2018-11-07")))
  event_xmod <- c(0,0,-20,15)
  event_ymod <- c(15,15,15,-15)
} else if(topic == "immi"){
  event <- data.frame(name=c("Family separation\nannounced",
                             "Executive order"),
                      date=as.Date(c("2018-04-06",
                                     "2018-06-20")))
  event_xmod <- c(5,12)
  event_ymod <- c(250,10)
}
event <- merge(event, mentions_tot)

#zoom in on relevant period
mentions_tot <- mentions_tot[mentions_tot$date > min(c(event$date,
                                                       prepost$pre_start))-30 &
                                 mentions_tot$date < max(c(event$date,
                                                           prepost$post_end))+30,]


##Add shows recorded per week

#shows per week
mentions_tot$weekof <- get_weekof(mentions_tot$date)
shows_week <- tapply(airings$show, airings$weekof, function(x) length(unique(x)))
shows_week <- data.frame(weekof=as.Date(names(shows_week)), shows_week=shows_week)
mentions_tot <- merge(mentions_tot, shows_week, all.x = T)


##Plots

#shows per week and events
prop <- (max(mentions_tot$count_ls)/max(mentions_tot$shows_week, na.rm=T))*1.15
p <- ggplot(mentions_tot, aes(x=date, y=count_ls, group=post_event)) + 
  geom_line() +
  ylab(paste0("Mentions of ", fulltop)) +
  #shows per week
  geom_line(aes(y = shows_week*prop), color="dark grey") +
  scale_y_continuous(sec.axis = sec_axis(~./prop, name = "Radio shows recorded")) +
  theme(axis.title.x=element_blank(),
        axis.line.y.right = element_line(color = "dark grey"), 
        axis.ticks.y.right = element_line(color = "dark grey"), 
        axis.title.y.right = element_text(color = "dark grey")) +
  #events
  geom_point(data=event) +
  annotate("text",
           x = event$date + event_xmod, #
           y = event$count_ls + event_ymod, # 
           label = event$name, lineheight=1)

#pre/post weeks from Google Trends
for(i in 1:nrow(prepost)){ 
    p <- p + annotate("rect", fill="orangered", alpha=.5, ymin=0, ymax=Inf,
                      xmin=as.Date(prepost$pre_start[i]),
                      xmax=as.Date(prepost$pre_end[i]))
    p <- p + annotate("rect", fill="orangered4", alpha=.5, ymin=0, ymax=Inf,
                      xmin=as.Date(prepost$post_start[i]),
                      xmax=as.Date(prepost$post_end[i]))
}
print(p)

#write to file
ggsave(paste0("../figures/mentions_GTrends_", topic,  ".pdf"))
