library(stargazer)
library(purrr)

fits_nb <- list()
coefs_nb <- list()
fits_fl_noclust <- list()
coefs_fl <- list()

topics <- c("clim","gun","immi")

for(topic in topics){
  
  load(paste0("regtables/modobj_", topic, ".Rdata"))
  fits_nb[[topic]] <- fit_nb
  coefs_nb[[topic]] <- coef_nb
  fits_fl_noclust[[topic]] <- fit_fl_noclust
  coefs_fl[[topic]] <- coef_fl
  
}

#negative binomial fits: get 
#coefficients, SEs, pvals 
est_nb <- coefs_nb %>% map(~.x[,1])
se_nb <- coefs_nb %>% map(~.x[,2])
p_nb <- coefs_nb %>% map(~.x[,4])
stargazer(fits_nb, coef=est_nb, se=se_nb, p=p_nb, column.labels=c("climate","gun","immig."),
          report = ('vc*sp'), out= "regtables/regtable_nb_counts.tex", #omit = c("Constant"),
          #digits=3, digits.extra=3, #this does not seem to limit number of digits in small p-values...
          dep.var.labels.include = F, dep.var.caption = "", keep.stat = c("n"),
          order=c(5,1,2,4,3), covariate.labels = c("Constant","post","liberal","post x liberal","minutes"),
          label="regtable_nb", title="Regression table for number of mentions of climate change, 
          gun policy and immigration. Model is negative binomial regression
          with standard errors clustered at the show level.")

#fractional logit fits
se_fl <- coefs_fl %>% map(~.x[,2])
p_fl <- coefs_fl %>% map(~.x[,4])
stargazer(fits_fl_noclust, se=se_fl, p=p_fl, column.labels=c("climate","gun","immig."),
          report = ('vc*sp'), out= "regtables/regtable_fl_positions.tex", #omit = c("Constant"),
          dep.var.labels.include = F, dep.var.caption = "", keep.stat = c("n"),
          order=c(4,1,2,3), covariate.labels = c("Constant","post","liberal","post x liberal"),
          label="regtable_fl", title="Regression table for proportion of mentions that are concerned about climate, 
          anti-gun, or tough on immigration. Model is fractional logit regression
          with standard errors clustered at the show level.")
